Package: packer
Title: An Opinionated Framework for Using 'JavaScript'
Date: 2022-05-28
Version: 0.1.3
Authors@R: 
    person(given = "John",
           family = "Coene",
           role = c("aut", "cre"),
           email = "jcoenep@gmail.com",
           comment = c(ORCID = "0000-0002-6637-4107"))
Description: 
  Enforces good practice and provides convenience functions to make work with 'JavaScript' 
  not just easier but also scalable. It is a robust wrapper to 'NPM', 'yarn', and 'webpack' that 
  enables to compartmentalize 'JavaScript' code, leverage 'NPM' and 'yarn' packages, include
  'TypeScript', 'React', or 'Vue' in web applications, and much more.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.0
Imports: fs, cli, usethis, jsonlite, roxygen2, rprojroot, rstudioapi,
        assertthat, htmlwidgets
URL: https://github.com/JohnCoene/packer, https://packer.john-coene.com
BugReports: https://github.com/JohnCoene/packer/issues
Suggests: testthat, covr, golem
Author: John Coene [aut, cre] (<https://orcid.org/0000-0002-6637-4107>)
Maintainer: John Coene <jcoenep@gmail.com>
Built: R 4.4.0; ; 2024-05-02 10:14:05 UTC; unix
