# Generated by roxygen2: do not edit by hand

S3method(roclet_output,roclet_dev)
S3method(roclet_output,roclet_prod)
S3method(roclet_process,roclet_dev)
S3method(roclet_process,roclet_prod)
export(add_jsdoc_tutorial)
export(add_plugin_clean)
export(add_plugin_eslint)
export(add_plugin_html)
export(add_plugin_jsdoc)
export(add_plugin_prettier)
export(add_plugin_workbox)
export(add_test_file)
export(apply_framework7)
export(apply_react)
export(apply_vue)
export(bundle)
export(bundle_dev)
export(bundle_prod)
export(checks)
export(dev_roclet)
export(ease_lit)
export(engine_adapt)
export(engine_check)
export(engine_console)
export(engine_get)
export(engine_set)
export(engine_which)
export(engine_yarn_install)
export(engine_yarn_set)
export(include_action_check)
export(include_tests_mocha)
export(include_tests_peeky)
export(make_library)
export(npm_console)
export(npm_fix)
export(npm_install)
export(npm_outdated)
export(npm_run)
export(npm_uninstall)
export(npm_update)
export(npx)
export(prod_roclet)
export(put_precommit_hook)
export(put_recommended)
export(put_rprofile_adapt)
export(put_test)
export(run_tests)
export(scaffold_ambiorix)
export(scaffold_bare)
export(scaffold_extension)
export(scaffold_golem)
export(scaffold_input)
export(scaffold_leprechaun)
export(scaffold_output)
export(scaffold_rmd)
export(scaffold_widget)
export(set_npm)
export(set_yarn)
export(tmp_ambiorix)
export(tmp_delete)
export(tmp_golem)
export(tmp_package)
export(tmp_project)
export(ts_get_type)
export(ts_get_types)
export(use_loader_babel)
export(use_loader_coffee)
export(use_loader_css)
export(use_loader_file)
export(use_loader_framework7)
export(use_loader_mocha)
export(use_loader_pug)
export(use_loader_rule)
export(use_loader_sass)
export(use_loader_style)
export(use_loader_svelte)
export(use_loader_ts)
export(use_loader_vue)
export(use_tailwind)
export(watch)
export(yarn_add)
export(yarn_clean)
export(yarn_console)
export(yarn_install)
export(yarn_outdated)
export(yarn_remove)
export(yarn_run)
export(yarn_upgrade)
export(yarn_version)
import(roxygen2)
importFrom(assertthat,assert_that)
importFrom(cli,cli_alert_info)
